@@ -18,8 +18,10 @@ import pecan
 from wsme import types as wtypes
 import wsmeext.pecan as wsme_pecan
 
-from mistral.api.controllers.v1 import workbook
 from mistral.api.controllers import resource
+from mistral.api.controllers.v1 import execution
+from mistral.api.controllers.v1 import task
+from mistral.api.controllers.v1 import workbook
 
 
 class RootResource(resource.Resource):
@@ -30,14 +32,17 @@ class RootResource(resource.Resource):
 
     uri = wtypes.text
 
-    # TODO: what else do we need here?
-    # TODO: we need to collect all the links from API v1.0 and provide them
+    # TODO(everyone): what else do we need here?
+    # TODO(everyone): we need to collect all the links from API v1.0
+    #                 and provide them.
 
 
 class Controller(object):
     """API root controller for version 1."""
 
     workbooks = workbook.WorkbooksController()
+    executions = execution.RootExecutionsController()
+    tasks = task.RootTasksController()
 
     @wsme_pecan.wsexpose(RootResource)
     def index(self):
