@@ -14,29 +14,23 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import os
-import tempfile
-import unittest2
-
-from oslo import messaging
-from oslo.config import cfg
-from oslo.messaging import transport
 import pkg_resources as pkg
+import sys
+import tempfile
+
+from oslo.config import cfg
+from oslo import messaging
+from oslo.messaging import transport
+from oslotest import base
 from stevedore import driver
+import testtools.matchers as ttm
 
-from mistral.openstack.common import importutils
-
-
-# We need to make sure that all configuration properties are registered.
-importutils.import_module("mistral.config")
-
+from mistral import context as auth_context
 from mistral.db.sqlalchemy import api as db_api
+from mistral import engine
+from mistral.engine import executor
 from mistral.openstack.common import log as logging
-from mistral.openstack.common.db.sqlalchemy import session
 from mistral import version
-from mistral.engine import client
-from mistral.engine.scalable import engine
-from mistral.engine.scalable.executor import server
 
 
 RESOURCES_PATH = 'tests/resources/'
@@ -66,16 +60,20 @@ def get_fake_transport():
     return transport.Transport(mgr.driver)
 
 
-class BaseTest(unittest2.TestCase):
-    def setUp(self):
-        super(BaseTest, self).setUp()
+class BaseTest(base.BaseTestCase):
+    def assertListEqual(self, l1, l2):
+        if tuple(sys.version_info)[0:2] < (2, 7):
+            # for python 2.6 compatibility
+            self.assertEqual(l1, l2)
+        else:
+            super(BaseTest, self).assertListEqual(l1, l2)
 
-        # TODO: add whatever is needed for all Mistral tests in here
-
-    def tearDown(self):
-        super(BaseTest, self).tearDown()
-
-        # TODO: add whatever is needed for all Mistral tests in here
+    def assertDictEqual(self, cmp1, cmp2):
+        if tuple(sys.version_info)[0:2] < (2, 7):
+            # for python 2.6 compatibility
+            self.assertThat(cmp1, ttm.Equals(cmp2))
+        else:
+            super(BaseTest, self).assertDictEqual(cmp1, cmp2)
 
     def _assert_single_item(self, items, **props):
         return self._assert_multiple_items(items, 1, **props)[0]
@@ -106,14 +104,20 @@ class BaseTest(unittest2.TestCase):
 
 class DbTestCase(BaseTest):
     def setUp(self):
-        self.db_fd, self.db_path = tempfile.mkstemp()
-        session.set_defaults('sqlite:///' + self.db_path, self.db_path)
+        super(DbTestCase, self).setUp()
+        _db_fd, self.db_path = tempfile.mkstemp()
+        cfg.CONF.set_default('connection', 'sqlite:///' + self.db_path,
+                             group='database')
         db_api.setup_db()
+        self.addCleanup(db_api.drop_db)
 
-    def tearDown(self):
-        db_api.drop_db()
-        os.close(self.db_fd)
-        os.unlink(self.db_path)
+        self.ctx = auth_context.MistralContext(user_id='1-2-3-4',
+                                               project_id='5-6-7-8',
+                                               user_name='test-user',
+                                               project_name='test-project',
+                                               is_admin=False)
+        auth_context.set_ctx(self.ctx)
+        self.addCleanup(auth_context.set_ctx, None)
 
     def is_db_session_open(self):
         return db_api._get_thread_local_session() is not None
@@ -121,54 +125,58 @@ class DbTestCase(BaseTest):
 
 class EngineTestCase(DbTestCase):
     transport = get_fake_transport()
+    backend = engine.get_engine(cfg.CONF.engine.engine, transport)
 
     def __init__(self, *args, **kwargs):
         super(EngineTestCase, self).__init__(*args, **kwargs)
-        self.engine = client.EngineClient(self.transport)
+        self.engine = engine.EngineClient(self.transport)
 
     @classmethod
-    def mock_task_result(cls, workbook_name, execution_id,
-                         task_id, state, result):
-        """
-        Mock the engine convey_task_results to send request directly
+    def mock_task_result(cls, task_id, state, result):
+        """Mock the engine convey_task_results to send request directly
         to the engine instead of going through the oslo.messaging transport.
         """
-        return engine.ScalableEngine.convey_task_result(
-            workbook_name, execution_id, task_id, state, result)
+        cntx = {}
+        kwargs = {'task_id': task_id,
+                  'state': state,
+                  'result': result}
+        return cls.backend.convey_task_result(cntx, **kwargs)
 
     @classmethod
     def mock_start_workflow(cls, workbook_name, task_name, context=None):
-        """
-        Mock the engine start_workflow_execution to send request directly
+        """Mock the engine start_workflow_execution to send request directly
         to the engine instead of going through the oslo.messaging transport.
         """
-        return engine.ScalableEngine.start_workflow_execution(
-            workbook_name, task_name, context)
+        cntx = {}
+        kwargs = {'workbook_name': workbook_name,
+                  'task_name': task_name,
+                  'context': context}
+        return cls.backend.start_workflow_execution(cntx, **kwargs)
 
     @classmethod
     def mock_get_workflow_state(cls, workbook_name, execution_id):
+        """Mock the engine get_workflow_execution_state to send request
+        directly to the engine instead of going through the oslo.messaging
+        transport.
         """
-        Mock the engine get_workflow_execution_state to send request directly
-        to the engine instead of going through the oslo.messaging transport.
-        """
-        return engine.ScalableEngine.get_workflow_execution_state(
-            workbook_name, execution_id)
+        cntx = {}
+        kwargs = {'workbook_name': workbook_name,
+                  'execution_id': execution_id}
+        return cls.backend.get_workflow_execution_state(cntx, **kwargs)
 
     @classmethod
     def mock_run_tasks(cls, tasks):
-        """
-        Mock the engine _run_tasks to send requests directly to the task
+        """Mock the engine _run_tasks to send requests directly to the task
         executor instead of going through the oslo.messaging transport.
         """
-        executor = server.Executor(transport=cls.transport)
+        exctr = executor.get_executor(cfg.CONF.engine.engine, cls.transport)
         for task in tasks:
-            executor.handle_task({}, task=task)
+            exctr.handle_task({}, task=task)
 
     @classmethod
     def mock_handle_task(cls, cntx, **kwargs):
-        """
-        Mock the executor handle_task to send requests directory to the task
+        """Mock the executor handle_task to send requests directory to the task
         executor instead of going through the oslo.messaging transport.
         """
-        executor = server.Executor(transport=cls.transport)
-        return executor.handle_task(cntx, **kwargs)
+        exctr = executor.get_executor(cfg.CONF.engine.engine, cls.transport)
+        return exctr.handle_task(cntx, **kwargs)
