@@ -14,14 +14,13 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-
-import unittest2
-from mock import patch, call
-
-from email.parser import Parser
+from email import parser
+import mock
+import testtools
 
 from mistral.actions import std_actions as std
 from mistral import exceptions as exc
+from mistral.tests import base
 
 """
 To try against a real SNMP server:
@@ -46,9 +45,10 @@ LOCAL_SMTPD = False
 REMOTE_SMTP = False
 
 
-class SendEmailActionTest(unittest2.TestCase):
+class SendEmailActionTest(base.BaseTest):
 
     def setUp(self):
+        super(SendEmailActionTest, self).setUp()
         self.params = {
             'to': ["dz@example.com, deg@example.com", "xyz@example.com"],
             'subject': "Multi word subject с русскими буквами",
@@ -60,12 +60,12 @@ class SendEmailActionTest(unittest2.TestCase):
         }
         self.to_addrs = ', '.join(self.params['to'])
 
-    @unittest2.skipIf(not LOCAL_SMTPD, "Setup local smtpd to run it")
+    @testtools.skipIf(not LOCAL_SMTPD, "Setup local smtpd to run it")
     def test_send_email_real(self):
         action = std.SendEmailAction(self.params, self.settings)
         action.run()
 
-    @unittest2.skipIf(not REMOTE_SMTP, "Configure Remote SMTP to run it")
+    @testtools.skipIf(not REMOTE_SMTP, "Configure Remote SMTP to run it")
     def test_with_password_real(self):
         self.params['to'] = ["dz@stackstorm.com"]
         self.settings = {
@@ -78,7 +78,7 @@ class SendEmailActionTest(unittest2.TestCase):
 
         action.run()
 
-    @patch('smtplib.SMTP')
+    @mock.patch('smtplib.SMTP')
     def test_send_email(self, smtp):
         action = std.SendEmailAction(self.params, self.settings)
 
@@ -94,14 +94,14 @@ class SendEmailActionTest(unittest2.TestCase):
         self.assertEqual(
             sendmail.call_args[1]['to_addrs'], self.to_addrs)
 
-        message = Parser().parsestr(sendmail.call_args[1]['msg'])
+        message = parser.Parser().parsestr(sendmail.call_args[1]['msg'])
 
         self.assertEqual(self.settings['from'], message['from'])
         self.assertEqual(self.to_addrs, message['to'])
         self.assertEqual(self.params['subject'], message['subject'])
         self.assertEqual(self.params['body'], message.get_payload())
 
-    @patch('smtplib.SMTP')
+    @mock.patch('smtplib.SMTP')
     def test_with_password(self, smtp):
         self.settings['password'] = "secret"
 
@@ -110,13 +110,14 @@ class SendEmailActionTest(unittest2.TestCase):
         action.run()
 
         smtpmock = smtp.return_value
-        calls = [call.ehlo(), call.starttls(), call.ehlo(),
-                 call.login(self.settings['from'], self.settings['password'])]
+        calls = [mock.call.ehlo(), mock.call.starttls(), mock.call.ehlo(),
+                 mock.call.login(self.settings['from'],
+                                 self.settings['password'])]
 
         smtpmock.assert_has_calls(calls)
         self.assertTrue(smtpmock.sendmail.called, "should call sendmail")
 
-    @patch('mistral.actions.std_actions.LOG')
+    @mock.patch('mistral.actions.std_actions.LOG')
     def test_exception(self, log):
         self.params['smtp_server'] = "wrong host"
 
